@@ -900,7 +900,7 @@ local function parse_expression_statement(state)
 
       if primary_expression.tag == "Call" or primary_expression.tag == "Invoke" then
          if lhs then
-            -- The is an assingment, and a call is not valid in lhs.
+            -- The is an assignment, and a call is not valid in lhs.
             parse_error(state, "expected call or indexing")
          else
             -- This is a call.
@@ -931,7 +931,7 @@ local function parse_expression_statement(state)
          parse_error(state, "compound assignment not allowed on tuples near " .. compound_operator .. "=")
       end
 
-      return new_inner_node(start_range, rhs[1], "OpSet", {compound_operator, lhs[1], rhs[1]})
+      return new_inner_node(start_range, rhs[1], "OpSet", {lhs, rhs, compound_operator})
    else
       -- This is an assignment in the form `lhs = rhs`.
       check_and_skip_token(state, "=")
